==> driftdb-0.0.2.tar.gz: driftdb-0.0.2/driftdb/drift_evaluator/drift_evaluators_dry_run.py <==
import traceback
from driftdb.drift_evaluator.drift_evaluators import (
    DriftEvaluatorContext,
    DriftEvaluator,
    parse_drift_summary,
)
from github import Github

import pandas as pd


def run_drift_evaluator(
    *,
    drift_evaluator: DriftEvaluator,
    gh_client: Github,
    repo_name: str,
    commit_sha: str
):
    #  get drift context from gh_client and commit_sha
    repo = gh_client.get_repo(repo_name)
    commit = repo.get_commit(commit_sha)
    file = commit.files[0]
    raw_content = repo.get_contents(file.filename, ref=commit_sha)
    parent_raw_content = repo.get_contents(file.filename, ref=commit.parents[0].sha)

    if isinstance(raw_content, list):
        raw_content = raw_content[0]

    if isinstance(parent_raw_content, list):
        parent_raw_content = parent_raw_content[0]

    new_dataframe = pd.read_csv(
        raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    old_dataframe = pd.read_csv(
        parent_raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    drift_summary = None
    try:
        commit_message = commit.commit.message
        drift_summary = parse_drift_summary(commit_message)
    except Exception as e:
        print("Failed to parse drift summary: " + str(e))
        traceback.print_exc()

    #  run drift evaluator
    data_drift_context = DriftEvaluatorContext(
        {
            "before": old_dataframe,
            "after": new_dataframe,
            "summary": drift_summary,
        }
    )
    try:
        drift_evaluation = drift_evaluator(data_drift_context)
        #  return result
        return drift_evaluation
    except Exception as e:
        print("Drift evaluator failed: " + str(e))
        traceback.print_exc()

==> driftdb-0.0.5.tar.gz: driftdb-0.0.5/driftdb/drift_evaluator/drift_evaluators_dry_run.py <==
import traceback

import pandas as pd
from github import Github

from ..logger import get_logger
from .drift_evaluators import BaseDriftEvaluator, BaseNewDataEvaluator, DriftEvaluatorContext, parse_drift_summary
from .interface import DriftEvaluation, NewDataEvaluatorContext

logger = get_logger(__name__)


def run_drift_evaluator(
    *, drift_evaluator: BaseDriftEvaluator, gh_client: Github, repo_name: str, commit_sha: str
) -> DriftEvaluation:
    repo = gh_client.get_repo(repo_name)
    commit = repo.get_commit(commit_sha)
    file = commit.files[0]
    raw_content = repo.get_contents(file.filename, ref=commit_sha)
    parent_raw_content = repo.get_contents(file.filename, ref=commit.parents[0].sha)

    if isinstance(raw_content, list):
        raw_content = raw_content[0]

    if isinstance(parent_raw_content, list):
        parent_raw_content = parent_raw_content[0]

    new_dataframe = pd.read_csv(
        raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    old_dataframe = pd.read_csv(
        parent_raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    drift_summary = None
    try:
        commit_message = commit.commit.message
        drift_summary = parse_drift_summary(commit_message)
    except Exception as e:
        logger.warn("Failed to parse drift summary: " + str(e))
        traceback.print_exc()

    #  run drift evaluator
    data_drift_context = DriftEvaluatorContext(
        before=old_dataframe,
        after=new_dataframe,
        summary=drift_summary,
    )
    drift_evaluation = drift_evaluator.compute_drift_evaluation(data_drift_context)
    return drift_evaluation


def run_new_data_evaluator(
    *, drift_evaluator: BaseNewDataEvaluator, gh_client: Github, repo_name: str, commit_sha: str
) -> DriftEvaluation:
    repo = gh_client.get_repo(repo_name)
    commit = repo.get_commit(commit_sha)
    file = commit.files[0]
    raw_content = repo.get_contents(file.filename, ref=commit_sha)
    parent_raw_content = repo.get_contents(file.filename, ref=commit.parents[0].sha)

    if isinstance(raw_content, list):
        raw_content = raw_content[0]

    if isinstance(parent_raw_content, list):
        parent_raw_content = parent_raw_content[0]

    new_dataframe = pd.read_csv(
        raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    old_dataframe = pd.read_csv(
        parent_raw_content.download_url,
        dtype="string",
        keep_default_na=False,
    )

    new_data = new_dataframe.loc[~new_dataframe["unique_key"].isin(old_dataframe["unique_key"])]

    #  run drift evaluator
    data_drift_context = NewDataEvaluatorContext(
        before=old_dataframe,
        after=new_dataframe,
        added_rows=new_data,
    )
    drift_evaluation = drift_evaluator.compute_new_data_evaluation(data_drift_context)
    return drift_evaluation
